@@ -2,5 +2,5 @@
 """
 
 from tasrif.processing_pipeline.kats.calculate_timeseries_properties_operator import (
-	CalculateTimeseriesPropertiesOperator
+    CalculateTimeseriesPropertiesOperator,
 )
