@@ -1,6 +1,8 @@
 """
 Module that provides mixins for commonly-used validations.
 """
+import types
+
 import pandas as pd
 
 
@@ -10,28 +12,47 @@ class ValidationError(Exception):
     """
 
 
-#pylint: disable=too-few-public-methods
+# pylint: disable=too-few-public-methods
 class InputsAreDataFramesValidatorMixin:
     """
     Validates whether the inputs to the operator are DataFrames.
     """
-    def _validate(self, *data_frames):  #pylint: disable=no-self-use
-        inputs_are_data_frames = [
-            isinstance(df, pd.DataFrame) for df in data_frames
-        ]
+
+    def _validate(self, *data_frames):  # pylint: disable=no-self-use
+        inputs_are_data_frames = [isinstance(df, pd.DataFrame) for df in data_frames]
         if not all(inputs_are_data_frames):
             raise ValidationError("Some inputs are not pandas.DataFrames!")
 
 
-#pylint: disable=too-few-public-methods
+# pylint: disable=too-few-public-methods
 class GroupbyCompatibleValidatorMixin:
     """
     Validates whether the inputs to the operator are compatible.
     """
-    def _validate(self, *data_frames):  #pylint: disable=no-self-use
+
+    def _validate(self, *data_frames):  # pylint: disable=no-self-use
         inputs_are_pandas_objects = [
-            isinstance(df, (pd.DataFrame, pd.Series,
-                            pd.core.groupby.generic.DataFrameGroupBy))
+            isinstance(
+                df, (pd.DataFrame, pd.Series, pd.core.groupby.generic.DataFrameGroupBy)
+            )
+            for df in data_frames
+        ]
+        if not all(inputs_are_pandas_objects):
+            raise ValidationError(
+                "Some inputs are not of the following types: \
+                pandas.DataFrames, pandas.Series or pandas.DataFrameGroupBy!"
+            )
+
+
+# pylint: disable=too-few-public-methods
+class GeneratorCompatibleValidatorMixin:
+    """
+    Validates whether the inputs to the operator are compatible.
+    """
+
+    def _validate(self, *data_frames):  # pylint: disable=no-self-use
+        inputs_are_pandas_objects = [
+            isinstance(df, (pd.DataFrame, pd.Series, types.GeneratorType))
             for df in data_frames
         ]
         if not all(inputs_are_pandas_objects):
